pub(crate) fn parse_selector_arg(s: &str) -> Result<SelectorArg, String>Expand description
Parse a selector string into a named selector argument.
pub(crate) fn parse_selector_arg(s: &str) -> Result<SelectorArg, String>Parse a selector string into a named selector argument.